// (C) 2023 GoodData Corporation
import React from "react";
import cx from "classnames";
import { useIntl } from "react-intl";
import { messages } from "@gooddata/sdk-ui";
import { Button } from "@gooddata/sdk-ui-kit";
/**
 *
 * @internal
 */
export const AttributeHierarchyDetailPanel = ({ title, description, attributes, onEdit, }) => {
    const { formatMessage } = useIntl();
    const hierarchyLevelsText = formatMessage(messages.hierarchyListLevels);
    const editText = formatMessage(messages.hierarchyListEdit);
    return (React.createElement("div", { className: "gd-attribute-hierarchy-detail-panel" },
        React.createElement("div", { className: "gd-attribute-hierarchy-detail-title" }, title),
        description ? (React.createElement("div", { className: "gd-attribute-hierarchy-detail-description" }, description)) : null,
        React.createElement("div", { className: "gd-attribute-hierarchy-detail-levels" }, hierarchyLevelsText),
        attributes.map((item, index) => {
            const itemClassNames = cx("gd-attribute-hierarchy-detail-item", {
                "is-date": item.isDate,
                "is-attribute": !item.isDate,
            });
            return (React.createElement("div", { key: index, className: itemClassNames }, item.title));
        }),
        onEdit ? (React.createElement("div", { className: "gd-attribute-hierarchy-detail-panel-actions s-gd-attribute-hierarchy-detail-panel-actions" },
            React.createElement(Button, { className: "gd-button-secondary gd-icon-pencil gd-button-small gd-attribute-hierarchy-detail-edit-button s-gd-attribute-hierarchy-detail-edit-button", value: editText, onClick: onEdit }))) : null));
};
//# sourceMappingURL=AttributeHierarchyDetailPanel.js.map