// (C) 2023 GoodData Corporation
import React from "react";
import { useIntl } from "react-intl";
import { ItemsWrapper, Item, Separator, Overlay } from "@gooddata/sdk-ui-kit";
import { messages } from "@gooddata/sdk-ui";
import { useAttributeHierarchyDialog } from "./AttributeHierarchyDialogProvider.js";
const ALIGN_POINTS = [{ align: "br tr" }];
const AddActionMenu = ({ rowIndex, alignTo, onClose }) => {
    const { formatMessage } = useIntl();
    const { onAddEmptyAttribute } = useAttributeHierarchyDialog();
    const handleAddAbove = () => {
        onAddEmptyAttribute(rowIndex - 1);
        onClose();
    };
    const handleAddBellow = () => {
        onAddEmptyAttribute(rowIndex);
        onClose();
    };
    const addAboveText = formatMessage(messages.hierarchyAddAttributeAbove);
    const addBellowText = formatMessage(messages.hierarchyAddAttributeBellow);
    return (React.createElement(Overlay, { alignTo: alignTo, alignPoints: ALIGN_POINTS, closeOnMouseDrag: true, closeOnOutsideClick: true, onClose: onClose, className: "attribute-hierarchy-add-action-menu s-attribute-hierarchy-add-action-menu" },
        React.createElement(ItemsWrapper, { smallItemsSpacing: true },
            React.createElement(Item, { onClick: handleAddAbove },
                React.createElement("i", { className: "gd-icon-arrow-up s-add-above" }),
                addAboveText),
            React.createElement(Separator, null),
            React.createElement(Item, { onClick: handleAddBellow },
                React.createElement("i", { className: "gd-icon-arrow-down s-add-below" }),
                addBellowText))));
};
export default AddActionMenu;
//# sourceMappingURL=AddActionMenu.js.map