// (C) 2023 GoodData Corporation
import React, { useEffect, useState } from "react";
import { useIntl } from "react-intl";
import { Dropdown, DropdownButton } from "@gooddata/sdk-ui-kit";
import { messages } from "@gooddata/sdk-ui";
import AttributeDropdownBody from "./AttributeDropdownBody.js";
import { useAttributeHierarchyDialog } from "./AttributeHierarchyDialogProvider.js";
const AttributeDropdown = ({ rowIndex }) => {
    const { formatMessage } = useIntl();
    const { getValidAttributes, onCompleteAttribute } = useAttributeHierarchyDialog();
    const [items, setItems] = useState([]);
    const [isLoading, setLoading] = useState(true);
    const handleSelect = (selectedItem) => {
        onCompleteAttribute(selectedItem, rowIndex);
    };
    useEffect(() => {
        getValidAttributes(rowIndex).then((attributes) => {
            setItems(attributes);
            setLoading(false);
        });
    }, [getValidAttributes, rowIndex]);
    const chooseAttributeText = formatMessage(messages.hierarchyAttributeDropdown);
    return (React.createElement(Dropdown, { className: "attribute-hierarchy-attribute-dropdown s-attribute-hierarchy-attribute-dropdown", closeOnParentScroll: true, closeOnMouseDrag: true, closeOnOutsideClick: true, openOnInit: true, renderButton: ({ isOpen, toggleDropdown }) => (React.createElement(DropdownButton, { className: "attribute-heirarchy-attribute-dropdown-button s-attribute-heirarchy-attribute-dropdown-button", value: chooseAttributeText, isOpen: isOpen, isSmall: true, onClick: toggleDropdown })), renderBody: ({ closeDropdown }) => {
            return (React.createElement(AttributeDropdownBody, { items: items, isLoading: isLoading, onSelect: handleSelect, closeDropdown: closeDropdown }));
        } }));
};
export default AttributeDropdown;
//# sourceMappingURL=AttributeDropdown.js.map