// (C) 2023 GoodData Corporation
import React from "react";
import { FormattedMessage, useIntl } from "react-intl";
import isEmpty from "lodash/isEmpty.js";
import { Button } from "@gooddata/sdk-ui-kit";
import { messages } from "@gooddata/sdk-ui";
import { useAttributeHierarchyDialog } from "./AttributeHierarchyDialogProvider.js";
const HOW_TO_WORK_DOCUMENTATION_LINK = "https://www.gooddata.com/docs/cloud/create-dashboards/drilling-in-dashboards/set-drill-down/";
const AttributeHierarchyDialogFooter = () => {
    const { formatMessage } = useIntl();
    const { isEditing, isDirty, isLoading, attributes, onSaveAttributeHierarchy, onClose, setDisplayDeleteConfirmation, } = useAttributeHierarchyDialog();
    const isSaveDisabled = isEmpty(attributes) || !isDirty;
    const onDelete = () => {
        setDisplayDeleteConfirmation(true);
    };
    const deleteText = formatMessage(messages.hierarchyDeleteButton);
    const cancelText = formatMessage(messages.hierarchyCancelButton);
    const saveText = formatMessage(isEditing ? messages.hierarchySaveButton : messages.hierarchyCreateButton);
    return (React.createElement("div", { className: "gd-dialog-footer" },
        React.createElement("div", { className: "attribute-hierarchy-note-message s-attribute-hierarchy-note-message" },
            React.createElement("div", { className: "gd-message progress" },
                React.createElement(FormattedMessage, { id: messages.hierarchyAttributeNoteMessage.id, values: {
                        b: (chunks) => React.createElement("strong", null, chunks),
                        br: () => React.createElement("br", null),
                    }, tagName: "div" }))),
        React.createElement("div", { className: "attribute-hierarchy-footer-actions-wrapper s-attribute-hierarchy-footer-actions-wrapper" },
            React.createElement("div", { className: "gd-dialog-footer-tip" },
                React.createElement("span", { className: "gd-icon-circle-question s-gd-icon-circle-question" }),
                React.createElement("a", { href: HOW_TO_WORK_DOCUMENTATION_LINK, className: "gd-button-link-dimmed", target: "_blank", rel: "noreferrer" },
                    React.createElement(FormattedMessage, { id: messages.hierarchyAttributeHowToWork.id }))),
            React.createElement("div", { className: "gd-dialog-footer-actions s-gd-dialog-footer-actions" },
                isEditing ? (React.createElement(Button, { className: "gd-button-link-dimmed attribute-hierarchy-delete-button s-attribute-hierarchy-delete-button", value: deleteText, onClick: onDelete, disabled: isLoading })) : null,
                React.createElement(Button, { className: "gd-button-secondary attribute-hierarchy-cancel-button s-attribute-hierarchy-cancel-button", value: cancelText, onClick: onClose, disabled: isLoading }),
                React.createElement(Button, { className: "gd-button-action attribute-hierarchy-save-button s-attribute-hierarchy-save-button", value: saveText, disabled: isSaveDisabled || isLoading, onClick: onSaveAttributeHierarchy })))));
};
export default AttributeHierarchyDialogFooter;
//# sourceMappingURL=AttributeHierarchyDialogFooter.js.map