import React, { ComponentProps } from "react";
import { FormattedMessage, WrappedComponentProps } from "react-intl";
import { IVisualizationProperties } from "../../interfaces/Visualization.js";
import { IAlignPoint } from "@gooddata/sdk-ui-kit";
export interface IInputControlProps {
    valuePath: string;
    properties: IVisualizationProperties;
    labelText?: string;
    value?: string;
    placeholder?: string;
    type?: string;
    max?: number;
    min?: number;
    step?: number;
    disabled?: boolean;
    showDisabledMessage?: boolean;
    disabledMessageId?: string;
    hasWarning?: boolean;
    disabledMessageAlignPoints?: IAlignPoint[];
    pushData?(data: any): void;
    validateAndPushDataCallback?(value: string): void;
    maxLength?: number;
    description?: string;
    descriptionValues?: ComponentProps<typeof FormattedMessage>["values"];
    /**
     * Optional function to validate the input value.
     * If the value is considered as invalid, it won't be set and emitted,
     * and last valid value will be used instead.
     *
     * @param value - the value to validate
     * @returns true if the value is valid, false otherwise
     */
    validateFn?: (value: string) => boolean;
    /**
     * Optional function to transform the input value, before it's sent via pushData callback.
     * This callback will be called only for valid values (see validateFn property).
     *
     * @param value - the value to transform
     * @returns the transformed value
     */
    transformFn?: (value: string) => string;
}
export interface IInputControlState {
    value?: string;
    lastSentValue?: string;
}
export declare class InputControl extends React.Component<IInputControlProps & WrappedComponentProps, IInputControlState> {
    static defaultProps: {
        value: string;
        type: string;
        disabled: boolean;
        pushData: (...args: any[]) => void;
        max: number;
        min: number;
        step: number;
        showDisabledMessage: boolean;
        hasWarning: boolean;
        validateAndPushDataCallback: (...args: any[]) => void;
    };
    private inputRef;
    constructor(props: IInputControlProps & WrappedComponentProps);
    UNSAFE_componentWillReceiveProps(newProps: IInputControlProps & WrappedComponentProps): void;
    render(): React.JSX.Element;
    private getInputClassNames;
    private isValid;
    private onValueChanged;
    private triggerBlur;
    private modifyDataForSending;
    private emitData;
    private onBlur;
    private onKeyPress;
}
declare const _default: React.FC<import("react-intl").WithIntlProps<IInputControlProps & WrappedComponentProps>> & {
    WrappedComponent: React.ComponentType<IInputControlProps & WrappedComponentProps>;
};
export default _default;
//# sourceMappingURL=InputControl.d.ts.map