// (C) 2019-2022 GoodData Corporation
import React from "react";
import { injectIntl } from "react-intl";
import { Message } from "@gooddata/sdk-ui-kit";
import ConfigSubsection from "../configurationControls/ConfigSubsection.js";
import InputControl from "../configurationControls/InputControl.js";
import { minInputValidateAndPushData, maxInputValidateAndPushData } from "../../utils/controlsHelper.js";
import { messages } from "../../../locales.js";
const defaultMinMaxControlState = {
    minScale: {
        hasWarning: false,
        warningMessage: "",
        incorrectValue: "",
    },
    maxScale: {
        hasWarning: false,
        warningMessage: "",
        incorrectValue: "",
    },
};
class MinMaxControl extends React.Component {
    static getDerivedStateFromProps(props) {
        if (props.propertiesMeta?.undoApplied) {
            return defaultMinMaxControlState;
        }
        return null;
    }
    constructor(props) {
        super(props);
        this.state = defaultMinMaxControlState;
    }
    render() {
        return this.renderMinMaxSection();
    }
    renderMinMaxSection() {
        const { properties, basePath, isDisabled } = this.props;
        const basePathPropertiesControls = properties?.controls?.[basePath];
        const axisScaleMin = basePathPropertiesControls?.min ?? "";
        const axisScaleMax = basePathPropertiesControls?.max ?? "";
        const axisVisible = basePathPropertiesControls?.visible ?? true;
        return (React.createElement(ConfigSubsection, { title: messages.axisScale.id },
            React.createElement(InputControl, { valuePath: `${basePath}.min`, labelText: messages.axisMin.id, placeholder: messages.autoPlaceholder.id, type: "number", hasWarning: this.minScaleHasWarning(), value: this.minScaleHasIncorrectValue() ? this.state.minScale?.incorrectValue : axisScaleMin, disabled: isDisabled || !axisVisible, properties: properties, pushData: this.minInputValidateAndPushDataCallback }),
            this.renderMinErrorMessage(),
            React.createElement(InputControl, { valuePath: `${basePath}.max`, labelText: messages.axisMax.id, placeholder: messages.autoPlaceholder.id, type: "number", hasWarning: this.maxScaleHasWarning(), value: this.maxScaleHasIncorrectValue() ? this.state.maxScale?.incorrectValue : axisScaleMax, disabled: isDisabled || !axisVisible, properties: properties, pushData: this.maxInputValidateAndPushDataCallback }),
            this.renderMaxErrorMessage()));
    }
    minInputValidateAndPushDataCallback = (data) => {
        minInputValidateAndPushData(data, this.state, this.props, this.setState.bind(this), defaultMinMaxControlState);
    };
    maxInputValidateAndPushDataCallback = (data) => {
        maxInputValidateAndPushData(data, this.state, this.props, this.setState.bind(this), defaultMinMaxControlState);
    };
    minScaleHasIncorrectValue() {
        return (this.state.minScale?.incorrectValue ?? "") !== "";
    }
    maxScaleHasIncorrectValue() {
        return (this.state.maxScale?.incorrectValue ?? "") !== "";
    }
    minScaleHasWarning() {
        return this.state.minScale?.hasWarning ?? false;
    }
    maxScaleHasWarning() {
        return this.state.maxScale?.hasWarning ?? false;
    }
    renderMinErrorMessage() {
        const minScaleWarningMessage = this.state.minScale?.warningMessage ?? "";
        if (!this.minScaleHasWarning() || minScaleWarningMessage === "") {
            return false;
        }
        return (React.createElement(Message, { type: "warning", className: "adi-input-warning" }, minScaleWarningMessage));
    }
    renderMaxErrorMessage() {
        const maxScaleWarningMessage = this.state.maxScale?.warningMessage ?? "";
        if (!this.maxScaleHasWarning() || maxScaleWarningMessage === "") {
            return false;
        }
        return (React.createElement(Message, { type: "warning", className: "adi-input-warning" }, maxScaleWarningMessage));
    }
}
export default injectIntl(MinMaxControl);
//# sourceMappingURL=MinMaxControl.js.map