// (C) 2023 GoodData Corporation
import React from "react";
import { injectIntl } from "react-intl";
import { getTranslatedDropdownItems } from "../../utils/translations.js";
import { messages } from "../../../locales.js";
import { orientationDropdownItems } from "../../constants/dropdowns.js";
import DropdownControl from "./DropdownControl.js";
export function convertXYNamePosition(namePosition) {
    if (!namePosition?.position) {
        return undefined;
    }
    const xAxisPosition = ["left", "center", "right"];
    const yAxisPosition = ["top", "middle", "bottom"];
    let currentPosition = xAxisPosition.indexOf(namePosition.position);
    if (currentPosition >= 0) {
        return { position: yAxisPosition[currentPosition] };
    }
    currentPosition = yAxisPosition.indexOf(namePosition.position);
    return { position: xAxisPosition[currentPosition] };
}
export function getAxesByChartOrientation(properties) {
    const { xaxis, yaxis } = properties?.controls || {};
    if (!xaxis && !yaxis) {
        return { xaxis, yaxis };
    }
    const resetProperties = {
        rotation: undefined,
        min: undefined,
        max: undefined,
        format: undefined,
    };
    const newXAxisName = convertXYNamePosition(yaxis?.name);
    const newYAxisName = convertXYNamePosition(xaxis?.name);
    return {
        xaxis: { ...resetProperties, ...yaxis, name: newXAxisName },
        yaxis: { ...resetProperties, ...xaxis, name: newYAxisName },
    };
}
class OrientationDropdownControl extends React.PureComponent {
    constructor(props) {
        super(props);
        this.handleOrientationChanged = this.handleOrientationChanged.bind(this);
    }
    handleOrientationChanged(data) {
        const { properties } = data;
        const isChanged = properties?.controls?.orientation?.position !==
            this.props.properties?.controls?.orientation?.position;
        if (isChanged) {
            const { xaxis, yaxis } = getAxesByChartOrientation(properties);
            const cloneProperties = {
                ...properties,
                controls: {
                    ...properties.controls,
                    ...(xaxis ? { xaxis } : {}),
                    ...(yaxis ? { yaxis } : {}),
                },
            };
            this.props.pushData({ ...data, properties: cloneProperties });
        }
        else {
            this.props.pushData(data);
        }
    }
    render() {
        return (React.createElement(DropdownControl, { value: this.props.value, valuePath: "orientation.position", labelText: messages.orientationTitle.id, disabled: this.props.disabled, properties: this.props.properties, pushData: this.handleOrientationChanged, items: this.generateDropdownItems(), showDisabledMessage: this.props.showDisabledMessage }));
    }
    generateDropdownItems() {
        return getTranslatedDropdownItems(orientationDropdownItems, this.props.intl);
    }
}
export default injectIntl(OrientationDropdownControl);
//# sourceMappingURL=OrientationDropdownControl.js.map