// (C) 2024 GoodData Corporation
import React, { useRef } from "react";
import { injectIntl } from "react-intl";
import cloneDeep from "lodash/cloneDeep.js";
import set from "lodash/set.js";
import cx from "classnames";
import { Button } from "@gooddata/sdk-ui-kit";
import { messages } from "../../../../locales.js";
import { ConfigSection } from "../ConfigSection.js";
import { ConfigEditor } from "./ConfigEditor.js";
import { useOverflow } from "./useOverflow.js";
const AdvancedSection = ({ properties, propertiesMeta, pushData, intl, controlsDisabled, }) => {
    const [showDialog, setShowDialog] = React.useState(false);
    const containerRef = useRef(null);
    const contentRef = useRef(null);
    const isOverflowing = useOverflow(containerRef.current, contentRef.current);
    const valuePath = "chartConfigOverride";
    const configurationValue = properties?.controls?.chartConfigOverride;
    const onChange = (value) => {
        const clonedProperties = cloneDeep(properties);
        set(clonedProperties, `controls.${valuePath}`, value);
        pushData({ properties: clonedProperties });
        setShowDialog(false);
    };
    return (React.createElement(React.Fragment, null,
        showDialog ? (React.createElement(ConfigEditor, { value: configurationValue, onSubmit: onChange, onCancel: () => setShowDialog(false) })) : null,
        React.createElement(ConfigSection, { id: "advanced_section", className: "gd-advanced-section", title: messages.advancedSection.id, propertiesMeta: propertiesMeta, pushData: pushData, intl: intl },
            configurationValue === undefined ? (React.createElement("div", { className: "gd-chart-override-no-value" }, intl.formatMessage(messages.chartConfigOverrideNoValueLabel))) : (React.createElement("div", { ref: containerRef, className: cx("gd-chart-override-value-preview", {
                    "fade-out": isOverflowing,
                }) },
                React.createElement("pre", { ref: contentRef, className: "gd-chart-override-value" }, configurationValue))),
            React.createElement(Button, { iconLeft: "gd-icon-code", className: "gd-button gd-button-small gd-button-secondary", onClick: () => setShowDialog(!showDialog), disabled: controlsDisabled }, intl.formatMessage(messages.chartConfigOverrideEditorButton)))));
};
export default injectIntl(React.memo(AdvancedSection));
//# sourceMappingURL=AdvancedSection.js.map