// (C) 2024 GoodData Corporation
import React from "react";
import { Overlay, Button, Hyperlink } from "@gooddata/sdk-ui-kit";
import { useIntl } from "react-intl";
import merge from "lodash/merge.js";
import * as jsYaml from "js-yaml";
import { messages } from "../../../../locales.js";
import { SNIPPETS } from "./snippets.js";
import { SnippetHeader, SnippetItem } from "./SnippetItem.js";
import { CodeMirrorEditor } from "./CodeMirrorEditor.js";
const EDITOR_ALIGN_POINTS = [
    {
        align: "br bl",
        offset: { x: 10, y: 0 },
    },
];
export const ConfigEditor = ({ value, onSubmit, onCancel }) => {
    const intl = useIntl();
    const [currentYamlValue, setCurrentYamlValue] = React.useState(value);
    const onSave = () => onSubmit(currentYamlValue === "" ? undefined : currentYamlValue);
    const onSnippet = (snippet) => {
        if (currentYamlValue === "" || currentYamlValue === undefined) {
            setCurrentYamlValue(jsYaml.dump(snippet.value));
            return;
        }
        try {
            const currentYamlValueAsJson = jsYaml.load(currentYamlValue);
            const mergedJson = merge(currentYamlValueAsJson, snippet.value);
            setCurrentYamlValue(jsYaml.dump(mergedJson));
        }
        catch (e) {
            console.error("Merging of snippet with current value failed. Current value has a lint error.", e);
        }
    };
    return (React.createElement(Overlay, { closeOnParentScroll: true, closeOnMouseDrag: true, closeOnOutsideClick: true, alignTo: ".gd-advanced-section", alignPoints: EDITOR_ALIGN_POINTS, onClose: onCancel },
        React.createElement("div", { className: "gd-dropdown overlay" },
            React.createElement("div", { className: "gd-advanced-customization-dialog" },
                React.createElement("div", { className: "gd-advanced-customization-dialog__header" },
                    React.createElement("span", null, intl.formatMessage(messages.chartConfigOverrideTitle)),
                    React.createElement("button", { className: "gd-button-link gd-button-icon-only gd-icon-cross", onClick: onCancel })),
                React.createElement("div", { className: "gd-advanced-customization-dialog__content" },
                    React.createElement("div", { className: "gd-advanced-customization-dialog__main" },
                        React.createElement(CodeMirrorEditor, { value: currentYamlValue, onChange: setCurrentYamlValue })),
                    React.createElement("div", { className: "gd-advanced-customization-dialog__snippets" },
                        React.createElement("div", { className: "gd-advanced-customization-dialog__snippets--header" },
                            React.createElement("div", null, intl.formatMessage(messages.snippetsHeader)),
                            React.createElement("div", { className: "gd-advanced-customization-dialog__snippets--header__line" })),
                        SNIPPETS.map((snippet) => snippet.type === "header" ? (React.createElement(SnippetHeader, { key: snippet.id, snippet: snippet })) : (React.createElement(SnippetItem, { key: snippet.id, snippet: snippet, onClick: onSnippet }))))),
                React.createElement("div", { className: "gd-advanced-customization-dialog__footer" },
                    React.createElement(Hyperlink, { iconClass: "gd-icon-circle-question", href: "https://www.gooddata.com/docs/cloud/", text: intl.formatMessage(messages.chartConfigOverrideLink), className: "gd-chart-override-link" }),
                    React.createElement("div", null,
                        React.createElement(Button, { className: "gd-button-secondary gd-button-small", onClick: onCancel, value: intl.formatMessage({
                                id: "properties.advanced.chartConfigOverride.button.cancel",
                            }) }),
                        React.createElement(Button, { className: "gd-button-action gd-button-small", onClick: onSave, value: intl.formatMessage({
                                id: "properties.advanced.chartConfigOverride.button.apply",
                            }) })))))));
};
//# sourceMappingURL=ConfigEditor.js.map