// (C) 2019-2022 GoodData Corporation
import React from "react";
import { injectIntl } from "react-intl";
import DropdownControl from "../DropdownControl.js";
import { getTranslatedDropdownItems } from "../../../utils/translations.js";
import { xAxisPositionDropdownItems, yAxisPositionDropdownItems } from "../../../constants/dropdowns.js";
import { messages } from "../../../../locales.js";
class NamePositionControl extends React.PureComponent {
    render() {
        const { axisVisible, axisNameVisible, namePosition } = this.getControlProperties();
        const { axis, properties, pushData, disabled, configPanelDisabled, intl } = this.props;
        const isDisabled = disabled || !axisVisible || !axisNameVisible;
        const items = getTranslatedDropdownItems(this.isXAxis() ? xAxisPositionDropdownItems : yAxisPositionDropdownItems, intl);
        return (React.createElement(DropdownControl, { value: namePosition, valuePath: `${axis}.name.position`, labelText: messages.axisNamePosition.id, disabled: isDisabled, showDisabledMessage: !configPanelDisabled && isDisabled, properties: properties, pushData: pushData, items: items }));
    }
    isXAxis() {
        const { axis } = this.props;
        return axis === "xaxis" || axis === "secondary_xaxis";
    }
    getControlProperties() {
        const axisProperties = this.props.properties?.controls?.[this.props.axis];
        const axisVisible = axisProperties?.visible ?? true;
        const axisNameVisible = axisProperties?.name?.visible ?? true;
        const namePosition = axisProperties?.name?.position ?? "auto";
        return {
            axisVisible,
            axisNameVisible,
            namePosition,
        };
    }
}
export default injectIntl(NamePositionControl);
//# sourceMappingURL=NamePositionControl.js.map