// (C) 2019-2023 GoodData Corporation
import React from "react";
import { injectIntl } from "react-intl";
import { DropdownList } from "@gooddata/sdk-ui-kit";
import ColoredItem from "./ColoredItem.js";
import { getSearchedItems } from "../../../../utils/colors.js";
const VISIBLE_ITEMS_COUNT = 5;
const SEARCHFIELD_VISIBILITY_THRESHOLD = 7;
const DROPDOWN_BODY_WIDTH = 218;
class ColoredItemsList extends React.PureComponent {
    static defaultProps = {
        disabled: false,
        isLoading: false,
    };
    listRef;
    constructor(props) {
        super(props);
        this.state = {
            searchString: "",
        };
        this.listRef = React.createRef();
    }
    render() {
        const searchString = this.isSearchFieldVisible() ? this.state.searchString : "";
        const items = getSearchedItems(this.props.inputItems, searchString);
        return (React.createElement("div", { ref: this.listRef },
            React.createElement(DropdownList, { width: DROPDOWN_BODY_WIDTH, showSearch: this.isSearchFieldVisible(), searchString: searchString, onSearch: this.onSearch, onScrollStart: this.onScroll, items: items, className: "gd-colored-items-list", maxVisibleItemsCount: VISIBLE_ITEMS_COUNT, isLoading: this.props.isLoading, renderItem: ({ item }) => (React.createElement(ColoredItem, { colorPalette: this.props.colorPalette, onSelect: this.onSelect, showCustomPicker: this.props.showCustomPicker, disabled: this.props.disabled, item: item })) })));
    }
    onScroll = () => {
        if (this.listRef?.current) {
            const node = this.listRef.current;
            node.dispatchEvent(new CustomEvent("goodstrap.scrolled", { bubbles: true }));
        }
    };
    closeOpenDropdownOnSearch() {
        // we have to close all dropdown ONE-3526
        // (IE has bug onClick on ClearIcon in Input doesn't fire click event and dropdown will not close)
        // so we can close it by onScroll event
        this.onScroll();
    }
    onSearch = (searchString) => {
        this.setState({ searchString });
        this.closeOpenDropdownOnSearch();
    };
    isSearchFieldVisible = () => {
        return this.props.inputItems.length > SEARCHFIELD_VISIBILITY_THRESHOLD && !this.props.isLoading;
    };
    onSelect = (selectedColorItem, color) => {
        this.props.onSelect(selectedColorItem, color);
    };
}
export default injectIntl(ColoredItemsList);
//# sourceMappingURL=ColoredItemsList.js.map