// (C) 2023 GoodData Corporation
import React from "react";
import { getCalculationValuesDefault } from "@gooddata/sdk-ui-charts";
import { comparisonMessages } from "../../../../locales.js";
import { COMPARISON_ENABLED_VALUE_PATH } from "./ComparisonValuePath.js";
import ConfigSection from "../ConfigSection.js";
import CalculationControl from "./calculation/CalculationControl.js";
import ValueSubSection from "./values/ValueSubSection.js";
import IndicatorSubSection from "./indicators/IndicatorSubSection.js";
import LabelSubSection from "./label/LabelSubSection.js";
const ComparisonSection = ({ controlDisabled, disabledByVisualization, defaultCalculationType, separators, properties, propertiesMeta, colorPalette, pushData, }) => {
    const toggledOn = properties.controls?.comparison?.enabled;
    const comparisonDisabled = controlDisabled || disabledByVisualization;
    const sectionDisabled = comparisonDisabled || !toggledOn;
    const showDisabledMessage = !controlDisabled && disabledByVisualization;
    const calculationType = properties?.controls?.comparison?.calculationType || defaultCalculationType;
    const { defaultFormat, defaultLabelKeys } = getCalculationValuesDefault(calculationType);
    return (React.createElement(ConfigSection, { id: "comparison_section", valuePath: COMPARISON_ENABLED_VALUE_PATH, title: comparisonMessages.title.id, propertiesMeta: propertiesMeta, properties: properties, pushData: pushData, canBeToggled: true, toggleDisabled: comparisonDisabled, showDisabledMessage: showDisabledMessage, toggledOn: toggledOn },
        React.createElement(CalculationControl, { disabled: sectionDisabled, showDisabledMessage: showDisabledMessage, defaultCalculationType: defaultCalculationType, properties: properties, pushData: pushData }),
        React.createElement(ValueSubSection, { sectionDisabled: sectionDisabled, showDisabledMessage: showDisabledMessage, defaultFormat: defaultFormat, separators: separators, properties: properties, pushData: pushData }),
        React.createElement(IndicatorSubSection, { sectionDisabled: sectionDisabled, showDisabledMessage: showDisabledMessage, properties: properties, colorPalette: colorPalette, pushData: pushData }),
        React.createElement(LabelSubSection, { sectionDisabled: sectionDisabled, showDisabledMessage: showDisabledMessage, defaultLabelKeys: defaultLabelKeys, calculationType: calculationType, properties: properties, pushData: pushData })));
};
export default ComparisonSection;
//# sourceMappingURL=ComparisonSection.js.map