// (C) 2023 GoodData Corporation
import React from "react";
import { FormattedMessage } from "react-intl";
import startCase from "lodash/startCase.js";
import { comparisonMessages } from "../../../../../locales.js";
const SECTION_TITLE_KEYS = {
    example: comparisonMessages.calculationTooltipExampleSection.id,
    formula: comparisonMessages.calculationTooltipFormulaSection.id,
    formulaChange: comparisonMessages.calculationTooltipFormulaChangeSection.id,
    formulaDifference: comparisonMessages.calculationTooltipFormulaDifferenceSection.id,
};
const SECTION_CONTENT_KEYS = {
    exampleChange: comparisonMessages.calculatedAsChangeTooltipExample.id,
    useInChange: comparisonMessages.calculatedAsChangeTooltipUseIn.id,
    formulaChange: comparisonMessages.calculatedAsChangeTooltipFormula.id,
    exampleRatio: comparisonMessages.calculatedAsRatioTooltipExample.id,
    useInRatio: comparisonMessages.calculatedAsRatioTooltipUseIn.id,
    formulaRatio: comparisonMessages.calculatedAsRatioTooltipFormula.id,
    exampleDifference: comparisonMessages.calculatedAsDifferenceTooltipExample.id,
    useInDifference: comparisonMessages.calculatedAsDifferenceTooltipUseIn.id,
    formulaDifference: comparisonMessages.calculatedAsDifferenceTooltipFormula.id,
    exampleChangeDifference: comparisonMessages.calculatedAsChangeDifferenceTooltipExample.id,
    useInChangeDifference: comparisonMessages.calculatedAsChangeDifferenceTooltipUseIn.id,
};
const toPascalCase = (value) => {
    return startCase(value).replace(/\s/g, "");
};
const getSectionTitleKey = (section, calculationType, isSectionCombineCalculationType) => {
    const property = isSectionCombineCalculationType ? `${section}${toPascalCase(calculationType)}` : section;
    return SECTION_TITLE_KEYS[property];
};
const getSectionContentKey = (section, calculationType) => {
    const property = `${section}${toPascalCase(calculationType)}`;
    return SECTION_CONTENT_KEYS[property];
};
const CalculationListItemInfoSection = ({ calculationType, section, contentClassNames, shouldHideTitle, isSectionCombineCalculationType, }) => {
    const titleKey = getSectionTitleKey(section, calculationType, isSectionCombineCalculationType);
    const contentKey = getSectionContentKey(section, calculationType);
    return (React.createElement(React.Fragment, null,
        !shouldHideTitle ? React.createElement(FormattedMessage, { id: titleKey, tagName: "h4" }) : null,
        React.createElement("p", { className: contentClassNames },
            React.createElement(FormattedMessage, { id: contentKey }))));
};
export default CalculationListItemInfoSection;
//# sourceMappingURL=CalculationListItemInfoSection.js.map