// (C) 2019-2024 GoodData Corporation
import React from "react";
import ConfigSection from "../ConfigSection.js";
import ForecastConfidenceControl from "./ForecastConfidenceControl.js";
import InputControl from "../InputControl.js";
import { messages } from "../../../../locales.js";
import noop from "lodash/noop.js";
import CheckboxControl from "../CheckboxControl.js";
import { Message } from "@gooddata/sdk-ui-kit";
import { FormattedMessage } from "react-intl";
class ForecastSection extends React.PureComponent {
    static defaultProps = {
        controlsDisabled: false,
        enabled: false,
        properties: {},
        propertiesMeta: {},
        defaultForecastEnabled: false,
        pushData: noop,
    };
    render() {
        const { controlsDisabled, properties, pushData, defaultForecastEnabled, enabled } = this.props;
        const forecastEnabled = this.props.properties?.controls?.forecast?.enabled ?? defaultForecastEnabled;
        const forecastConfidence = this.props.properties?.controls?.forecast?.confidence ?? 0.95;
        const forecastPeriod = this.props.properties?.controls?.forecast?.period ?? 3;
        const forecastSeasonal = this.props.properties?.controls?.forecast?.seasonal ?? false;
        const forecastToggleDisabledByVisualization = !(this.props.propertiesMeta?.forecast_enabled ?? true);
        const slicedForecast = this.props.propertiesMeta?.slicedForecast ?? false;
        const toggleDisabled = controlsDisabled || forecastToggleDisabledByVisualization || !enabled;
        const forecastControlsDisabled = !forecastEnabled || toggleDisabled;
        const showDisabledMessage = controlsDisabled || forecastToggleDisabledByVisualization || !enabled;
        return (React.createElement(ConfigSection, { id: "forecast_section", valuePath: "forecast.enabled", className: "gd-forecast-section", title: messages.forecastTitle.id, propertiesMeta: this.props.propertiesMeta, properties: properties, canBeToggled: true, toggleDisabled: toggleDisabled, toggledOn: forecastEnabled, pushData: pushData, showDisabledMessage: showDisabledMessage, toggleMessageId: messages.forecastDisabledTooltip.id },
            React.createElement(InputControl, { value: forecastPeriod, valuePath: "forecast.period", labelText: messages.forecastPeriod.id, placeholder: messages.forecastPeriodPlaceholder.id, disabled: forecastControlsDisabled, properties: properties, pushData: pushData }),
            React.createElement(ForecastConfidenceControl, { disabled: forecastControlsDisabled, value: forecastConfidence, showDisabledMessage: showDisabledMessage, properties: properties, pushData: pushData }),
            React.createElement(CheckboxControl, { valuePath: "forecast.seasonal", checked: forecastSeasonal, labelText: messages.forecastSeasonal.id, disabled: forecastControlsDisabled, properties: properties, pushData: pushData }),
            Boolean(slicedForecast) && (React.createElement(Message, { type: "progress", className: "adi-input-progress gd-slicedForecast-message" },
                React.createElement(FormattedMessage, { id: messages.forecastSlicedWarningTitle.id, tagName: "strong" }),
                React.createElement(FormattedMessage, { id: messages.forecastSlicedWarningDescription.id, tagName: "div" })))));
    }
}
export default ForecastSection;
//# sourceMappingURL=ForecastSection.js.map