// (C) 2023-2025 GoodData Corporation
import React from "react";
import { FormattedMessage, injectIntl } from "react-intl";
import ConfigSection from "../ConfigSection.js";
import { messages } from "../../../../locales.js";
import CheckboxControl from "../CheckboxControl.js";
import { Bubble, BubbleHoverTrigger, SeparatorLine } from "@gooddata/sdk-ui-kit";
const TOOLTIP_ALIGN_POINTS = [{ align: "cr cl", offset: { x: 5, y: 0 } }];
export const QuestionMarkTooltip = (props) => {
    return (React.createElement(BubbleHoverTrigger, null,
        React.createElement("span", { className: "gd-interactions-section__question-mark gd-icon-circle-question" }),
        React.createElement(Bubble, { alignPoints: TOOLTIP_ALIGN_POINTS },
            React.createElement(FormattedMessage, { id: props.tooltipText }))));
};
const InteractionsSection = (props) => {
    const { areControlsDisabledGetter, properties, propertiesMeta, pushData, InteractionsDetailRenderer, supportsAlertConfiguration, supportsDrillDownConfiguration, supportsScheduledExportsConfiguration, } = props;
    const isDrillDownDisabled = properties?.controls?.disableDrillDown ?? false;
    const isAlertsDisabled = properties?.controls?.disableAlerts ?? false;
    const isScheduledExportsDisabled = properties?.controls?.disableScheduledExports ?? false;
    const isSeparatorVisible = supportsDrillDownConfiguration &&
        (supportsAlertConfiguration || supportsScheduledExportsConfiguration);
    return (React.createElement(ConfigSection, { id: "interactions_section", className: "gd-interactions-section", title: messages.interactions.id, propertiesMeta: propertiesMeta, pushData: pushData },
        supportsAlertConfiguration ? (React.createElement("div", { className: "gd-interactions-section__control-with-tooltip" },
            React.createElement(CheckboxControl, { valuePath: "disableAlerts", labelText: messages.interactionsAlerts.id, properties: properties, disabled: areControlsDisabledGetter("interactions.alerts"), checked: !isAlertsDisabled, pushData: pushData, isValueInverted: true }),
            React.createElement(QuestionMarkTooltip, { tooltipText: messages.interactionsAlertsTooltip.id }))) : null,
        supportsScheduledExportsConfiguration ? (React.createElement("div", { className: "gd-interactions-section__control-with-tooltip" },
            React.createElement(CheckboxControl, { valuePath: "disableScheduledExports", labelText: messages.interactionsScheduledExports.id, properties: properties, disabled: areControlsDisabledGetter("interactions.scheduled_exports"), checked: !isScheduledExportsDisabled, pushData: pushData, isValueInverted: true }),
            React.createElement(QuestionMarkTooltip, { tooltipText: messages.interactionsScheduledExportsTooltip.id }))) : null,
        isSeparatorVisible ? React.createElement(SeparatorLine, { mT: 10, mB: 10 }) : null,
        supportsDrillDownConfiguration ? (React.createElement(CheckboxControl, { valuePath: "disableDrillDown", labelText: messages.interactionsDrillDown.id, properties: properties, disabled: areControlsDisabledGetter("interactions.drill_down"), checked: !isDrillDownDisabled, pushData: pushData, isValueInverted: true })) : null,
        InteractionsDetailRenderer ? InteractionsDetailRenderer() : null));
};
export default injectIntl(React.memo(InteractionsSection));
//# sourceMappingURL=InteractionsSection.js.map