import React from "react";
import { ChartType } from "@gooddata/sdk-ui";
import { IInsightDefinition, ISettings } from "@gooddata/sdk-model";
import { IReferences, IVisualizationProperties, IConfigurationPanelRenderers, IReferencePoint } from "../../interfaces/Visualization.js";
import { IColorConfiguration } from "../../interfaces/Colors.js";
import { SectionName } from "./sectionName.js";
export interface IConfigurationPanelContentProps<PanelConfig = any> {
    properties?: IVisualizationProperties;
    references?: IReferences;
    referencePoint?: IReferencePoint;
    propertiesMeta?: any;
    colors?: IColorConfiguration;
    locale: string;
    type?: ChartType;
    isError?: boolean;
    isLoading?: boolean;
    insight?: IInsightDefinition;
    featureFlags?: ISettings;
    axis?: string;
    pushData?(data: any): void;
    panelConfig?: PanelConfig;
    configurationPanelRenderers?: IConfigurationPanelRenderers;
}
export default abstract class ConfigurationPanelContent<T extends IConfigurationPanelContentProps = IConfigurationPanelContentProps> extends React.PureComponent<T> {
    static defaultProps: IConfigurationPanelContentProps;
    protected supportedPropertiesList: string[];
    constructor(props: T);
    render(): React.JSX.Element;
    protected abstract renderConfigurationPanel(): React.ReactNode;
    /**
     * Optionally pass a sectionName to specialize disabling logic for specific sections.
     * Default logic disables if no measures, error, or loading.
     */
    protected isControlDisabled(_sectionName?: SectionName): boolean;
    protected renderColorSection(): React.ReactNode;
    protected renderLegendSection(): React.ReactNode;
    protected renderInteractionsSection(): React.ReactNode;
    protected renderForecastSection(): React.ReactNode;
    protected renderAdvancedSection(): React.ReactNode;
}
//# sourceMappingURL=ConfigurationPanelContent.d.ts.map