// (C) 2019-2025 GoodData Corporation
import React from "react";
import noop from "lodash/noop.js";
import { DefaultLocale } from "@gooddata/sdk-ui";
import { insightHasMeasures } from "@gooddata/sdk-model";
import ColorsSection from "../configurationControls/colors/ColorsSection.js";
import LegendSection from "../configurationControls/legend/LegendSection.js";
import { InternalIntlWrapper } from "../../utils/internalIntlProvider.js";
import { getMeasuresFromMdObject } from "../../utils/bucketHelper.js";
import InteractionsSection from "../configurationControls/interactions/InteractionsSection.js";
import ForecastSection from "../configurationControls/forecast/ForecastSection.js";
import { isForecastEnabled } from "../../utils/forecastHelper.js";
import { isInsightSupportedForAlerts, isInsightSupportedForScheduledExports, } from "../pluggableVisualizations/alerts.js";
import AdvancedSection from "../configurationControls/advanced/AdvancedSection.js";
export default class ConfigurationPanelContent extends React.PureComponent {
    static defaultProps = {
        properties: null,
        references: null,
        referencePoint: null,
        propertiesMeta: null,
        colors: null,
        locale: DefaultLocale,
        isError: false,
        isLoading: false,
        insight: null,
        pushData: noop,
        featureFlags: {},
        axis: null,
        panelConfig: {},
    };
    supportedPropertiesList;
    constructor(props) {
        super(props);
        this.isControlDisabled = this.isControlDisabled.bind(this);
    }
    render() {
        return (React.createElement("div", { key: `config-${this.props.type}` },
            React.createElement(InternalIntlWrapper, { locale: this.props.locale }, this.renderConfigurationPanel())));
    }
    /**
     * Optionally pass a sectionName to specialize disabling logic for specific sections.
     * Default logic disables if no measures, error, or loading.
     */
    isControlDisabled(_sectionName) {
        const { insight, isError, isLoading } = this.props;
        return !insight || !insightHasMeasures(insight) || isError || isLoading;
    }
    renderColorSection() {
        const { properties, propertiesMeta, pushData, colors, featureFlags, references, insight, isLoading } = this.props;
        const controlsDisabled = this.isControlDisabled();
        const hasMeasures = getMeasuresFromMdObject(insight).length > 0;
        return (React.createElement(ColorsSection, { properties: properties, propertiesMeta: propertiesMeta, references: references, colors: colors, controlsDisabled: controlsDisabled, pushData: pushData, hasMeasures: hasMeasures, showCustomPicker: featureFlags.enableCustomColorPicker, isLoading: isLoading }));
    }
    renderLegendSection() {
        const { properties, propertiesMeta, pushData } = this.props;
        const controlsDisabled = this.isControlDisabled();
        return (React.createElement(LegendSection, { properties: properties, propertiesMeta: propertiesMeta, controlsDisabled: controlsDisabled, pushData: pushData }));
    }
    renderInteractionsSection() {
        const { pushData, properties, propertiesMeta, panelConfig, configurationPanelRenderers, featureFlags, insight, } = this.props;
        const isAlertingEnabled = featureFlags.enableAlerting;
        const isScheduledExportsEnabled = featureFlags.enableScheduling;
        const insightSupportsScheduledExports = isInsightSupportedForScheduledExports(insight);
        const insightSupportsAlerts = isInsightSupportedForAlerts(insight);
        const supportsAlertsConfiguration = insightSupportsAlerts && isAlertingEnabled;
        const supportsScheduledExportsConfiguration = insightSupportsScheduledExports && isScheduledExportsEnabled;
        return supportsAlertsConfiguration || panelConfig.supportsAttributeHierarchies ? (React.createElement(InteractionsSection, { areControlsDisabledGetter: this.isControlDisabled, properties: properties, propertiesMeta: propertiesMeta, pushData: pushData, supportsAlertConfiguration: supportsAlertsConfiguration, supportsDrillDownConfiguration: panelConfig.supportsAttributeHierarchies, supportsScheduledExportsConfiguration: supportsScheduledExportsConfiguration, InteractionsDetailRenderer: configurationPanelRenderers?.InteractionsDetailRenderer })) : null;
    }
    renderForecastSection() {
        const { pushData, properties, propertiesMeta, type, featureFlags, referencePoint, insight } = this.props;
        if (!featureFlags.enableSmartFunctions) {
            return null;
        }
        const { enabled, visible } = isForecastEnabled(referencePoint, insight, type);
        if (!visible) {
            return null;
        }
        return (React.createElement(ForecastSection, { controlsDisabled: this.isControlDisabled(), properties: properties, propertiesMeta: propertiesMeta, enabled: enabled, pushData: pushData }));
    }
    renderAdvancedSection() {
        const { pushData, properties, propertiesMeta, featureFlags } = this.props;
        return featureFlags.enableVisualizationFineTuning ? (React.createElement(AdvancedSection, { controlsDisabled: this.isControlDisabled(), properties: properties, propertiesMeta: propertiesMeta, pushData: pushData })) : null;
    }
}
//# sourceMappingURL=ConfigurationPanelContent.js.map