// (C) 2023-2024 GoodData Corporation
import { useIntl } from "react-intl";
import React, { useCallback } from "react";
import { BackButton, ConfirmDialogBase } from "@gooddata/sdk-ui-kit";
import { messages } from "../locales.js";
import { AddDataSourceSelect } from "./AddDataSourceSelect.js";
import { DataSourceList } from "./DataSourceList.js";
import { useAddDataSource } from "./useAddDataSource.js";
export const AddDataSource = ({ ids, subjectType, grantedDataSources, enableBackButton, onSubmit, onCancel, onClose, renderDataSourceIcon, }) => {
    const intl = useIntl();
    const { addedDataSources, isProcessing, onAdd, onDelete, onChange, onSelect } = useAddDataSource(ids, subjectType, onSubmit, onCancel);
    const backButtonRenderer = useCallback(() => {
        return React.createElement(BackButton, { onClick: onCancel, className: "s-user-management-navigate-back" });
    }, [onCancel]);
    return (React.createElement(ConfirmDialogBase, { className: "gd-share-dialog gd-share-dialog-add-users s-user-management-add-data-source", displayCloseButton: true, isPositive: true, isSubmitDisabled: addedDataSources.length === 0 || isProcessing, showProgressIndicator: isProcessing, headline: intl.formatMessage(messages.addDataSourceDialogTitle), cancelButtonText: intl.formatMessage(messages.addWorkspaceDialogCloseButton), submitButtonText: intl.formatMessage(messages.addWorkspaceDialogSaveButton), onCancel: onCancel, onSubmit: onAdd, onClose: onClose, headerLeftButtonRenderer: enableBackButton ? backButtonRenderer : undefined },
        React.createElement(AddDataSourceSelect, { addedDataSources: addedDataSources, grantedDataSources: grantedDataSources, onSelectDataSource: onSelect }),
        React.createElement(DataSourceList, { subjectType: subjectType, mode: "EDIT", dataSources: addedDataSources, onDelete: onDelete, onChange: onChange, renderDataSourceIcon: renderDataSourceIcon })));
};
//# sourceMappingURL=AddDataSource.js.map