// (C) 2023-2024 GoodData Corporation
import React, { useCallback, useMemo } from "react";
import { useIntl } from "react-intl";
import cx from "classnames";
import { dataSourcePermissionMessages } from "./locales.js";
import { QuestionMarkIcon } from "./QuestionMarkIcon.js";
export const PermissionDropdownItem = ({ permission, selectedPermission, toggleDropdown, onSelect, bubbleTextId, }) => {
    const intl = useIntl();
    const handleOnChange = useCallback(() => {
        if (permission.enabled) {
            toggleDropdown();
            onSelect(permission.id);
        }
    }, [permission, onSelect, toggleDropdown]);
    const isSelected = useMemo(() => permission.id === selectedPermission, [permission, selectedPermission]);
    return (React.createElement("div", { onClick: handleOnChange, className: cx("gd-list-item", "gd-menu-item", "gd-granular-permission-select-item", "gd-user-management-permission-item", "s-user-management-permission-item", {
            "is-disabled": !permission.enabled,
            "is-selected": isSelected,
        }) },
        React.createElement("div", null, intl.formatMessage(dataSourcePermissionMessages[permission.id])),
        React.createElement("div", { className: "gd-user-management-help-icon-wrapper" },
            React.createElement(QuestionMarkIcon, { bubbleTextId: bubbleTextId }))));
};
//# sourceMappingURL=PermissionsDropdownItem.js.map