// (C) 2023-2024 GoodData Corporation
import React, { useCallback } from "react";
import { useIntl, defineMessages } from "react-intl";
import cx from "classnames";
import { ItemsWrapper, Separator, Overlay } from "@gooddata/sdk-ui-kit";
import { dataSourcePermissionMessages } from "./locales.js";
import { PermissionDropdownItem } from "./PermissionsDropdownItem.js";
const userGroupTooltipMessages = defineMessages({
    USE: { id: "userManagement.dataSources.permissionGroup.use.tooltip" },
    MANAGE: { id: "userManagement.dataSources.permissionGroup.manage.tooltip" },
});
const userTooltipMessages = defineMessages({
    USE: { id: "userManagement.dataSources.permissionUser.use.tooltip" },
    MANAGE: { id: "userManagement.dataSources.permissionUser.manage.tooltip" },
});
const overlayAlignPoints = [{ align: "br tr" }];
const RemoveItem = ({ disabled, onClick }) => {
    const intl = useIntl();
    const className = cx("gd-list-item gd-menu-item gd-menu-item-remove", "s-user-management-permission-remove", {
        "is-disabled": disabled,
    });
    return (React.createElement("div", { className: className, onClick: onClick }, intl.formatMessage(dataSourcePermissionMessages.remove)));
};
export const PermissionsDropdownList = ({ items, subjectType, alignTo, isShowDropdown, selectedPermission, toggleDropdown, onSelect, onDelete, }) => {
    const tooltipSource = subjectType === "user" ? userTooltipMessages : userGroupTooltipMessages;
    const handleOnSelect = useCallback((permission) => {
        onSelect(permission);
        toggleDropdown();
    }, [onSelect, toggleDropdown]);
    const handleOnDelete = useCallback(() => {
        onDelete();
        toggleDropdown();
    }, [onDelete, toggleDropdown]);
    if (!isShowDropdown) {
        return null;
    }
    return (React.createElement(Overlay, { key: "GranularPermissionsSelect", alignTo: alignTo, alignPoints: overlayAlignPoints, className: "s-user-management-permissions-overlay", closeOnMouseDrag: true, closeOnOutsideClick: true, closeOnParentScroll: true, onClose: toggleDropdown },
        React.createElement(ItemsWrapper, { smallItemsSpacing: true },
            items.map((permissionItem) => {
                return (React.createElement(PermissionDropdownItem, { key: permissionItem.id, permission: permissionItem, selectedPermission: selectedPermission, toggleDropdown: toggleDropdown, onSelect: handleOnSelect, bubbleTextId: tooltipSource[permissionItem.id].id }));
            }),
            React.createElement(Separator, null),
            React.createElement(RemoveItem, { onClick: handleOnDelete }))));
};
//# sourceMappingURL=PermissionsDropdownList.js.map