// (C) 2023 GoodData Corporation
import { useIntl } from "react-intl";
import React, { useCallback, useEffect } from "react";
import { BackButton, ConfirmDialogBase } from "@gooddata/sdk-ui-kit";
import { extractUserName } from "../utils.js";
import { messages } from "../locales.js";
import { UserDetailsView } from "./UserDetailsView.js";
import { useUserDetails } from "./detailsHooks.js";
export const EditUserDetails = ({ user, isBootstrapUser, isAdmin, enableBackButton, changeUserMembership, onSubmit, onCancel, onClose, removeAdminGroup, }) => {
    const intl = useIntl();
    const { updatedUser, isUpdatedAdmin, isProcessing, onSave, onChange, isDirty } = useUserDetails(user, isAdmin, onSubmit, onCancel, removeAdminGroup);
    // change user membership if dialog was opened for that reason, enable Save button, do it just once
    useEffect(() => {
        if (changeUserMembership) {
            onChange(updatedUser, !isUpdatedAdmin);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const backButtonRenderer = useCallback(() => {
        return React.createElement(BackButton, { onClick: onCancel, className: "s-user-management-navigate-back" });
    }, [onCancel]);
    return (React.createElement(ConfirmDialogBase, { className: "gd-share-dialog gd-share-dialog-add-users s-user-management-edit-user", displayCloseButton: true, isPositive: true, isSubmitDisabled: !isDirty || isProcessing, showProgressIndicator: isProcessing, headline: extractUserName(user), cancelButtonText: intl.formatMessage(messages.closeEditMode), submitButtonText: intl.formatMessage(messages.saveEditedDetails), onCancel: onCancel, onSubmit: onSave, onClose: onClose, headerLeftButtonRenderer: enableBackButton ? backButtonRenderer : undefined },
        React.createElement(UserDetailsView, { user: updatedUser, isAdmin: isUpdatedAdmin, isBootstrapUser: isBootstrapUser, mode: "EDIT", onChange: onChange })));
};
//# sourceMappingURL=EditUserDetails.js.map