// (C) 2023 GoodData Corporation
import React, { useCallback, useMemo } from "react";
import { useIntl } from "react-intl";
import cx from "classnames";
import { Overlay, DropdownButton, Dropdown, ItemsWrapper } from "@gooddata/sdk-ui-kit";
import { messages } from "../locales.js";
import { QuestionMarkIcon } from "../Workspace/WorkspaceItem/QuestionMarkIcon.js";
const overlayAlignPoints = [{ align: "br tr" }];
export const OrganizationMemberDropdown = ({ isAdmin, isDisabled, onChange, }) => {
    const intl = useIntl();
    const renderDropdownBody = useCallback(({ closeDropdown }) => (React.createElement(Overlay, { key: "GranularPermissionsSelect", alignTo: ".gd-user-management-dialog-detail-organization-membership", alignPoints: overlayAlignPoints, className: "s-user-management-user-permissions-overlay", closeOnMouseDrag: true, closeOnOutsideClick: true, closeOnParentScroll: true, onClose: closeDropdown },
        React.createElement(ItemsWrapper, { smallItemsSpacing: true },
            React.createElement("div", { onClick: () => {
                    onChange(true);
                    closeDropdown();
                }, className: cx("gd-list-item", "gd-menu-item", "gd-user-management-dialog-detail-input", "gd-user-management-permission-item", "s-user-management-permission-admin", {
                    "is-selected": isAdmin,
                }) },
                React.createElement("div", null, intl.formatMessage(messages.userIsAdmin)),
                React.createElement("div", { className: "gd-user-management-help-icon-wrapper" },
                    React.createElement(QuestionMarkIcon, { bubbleTextId: messages.userIsAdminTooltip.id }))),
            React.createElement("div", { onClick: () => {
                    onChange(false);
                    closeDropdown();
                }, className: cx("gd-list-item", "gd-menu-item", "gd-user-management-dialog-detail-input", "gd-user-management-permission-item", "s-user-management-permission-non-admin", {
                    "is-selected": !isAdmin,
                }) },
                React.createElement("div", null, intl.formatMessage(messages.userIsRegularUser)),
                React.createElement("div", { className: "gd-user-management-help-icon-wrapper" },
                    React.createElement(QuestionMarkIcon, { bubbleTextId: messages.userIsRegularUserTooltip.id })))))), [isAdmin, onChange, intl]);
    const selectedValue = useMemo(() => isAdmin
        ? intl.formatMessage(messages.userIsAdmin)
        : intl.formatMessage(messages.userIsRegularUser), [isAdmin, intl]);
    const renderDropdownButton = useCallback(({ openDropdown, isOpen }) => (React.createElement(DropdownButton, { value: selectedValue, isOpen: isOpen, disabled: isDisabled, onClick: openDropdown, isSmall: false, className: "gd-user-management-dialog-detail-organization-membership gd-user-management-dialog-detail-input s-user-management-permission-dropdown" })), [selectedValue, isDisabled]);
    return React.createElement(Dropdown, { renderBody: renderDropdownBody, renderButton: renderDropdownButton });
};
//# sourceMappingURL=OrganizationMemberDropdown.js.map