// (C) 2023 GoodData Corporation
import React from "react";
import { useIntl } from "react-intl";
import noop from "lodash/noop.js";
import { messages } from "../locales.js";
import { useTelemetry } from "../TelemetryContext.js";
import { OrganizationMemberDropdown } from "./OrganizationMemberDropdown.js";
import { DetailRow } from "./DetailRow.js";
export const UserDetailsView = ({ user, isAdmin, isBootstrapUser, mode, onChange, }) => {
    const intl = useIntl();
    const trackEvent = useTelemetry();
    if (!user) {
        return null;
    }
    return (React.createElement("div", { className: "gd-user-management-dialog-detail s-user-management-user" },
        React.createElement(DetailRow, { labelText: intl.formatMessage(messages.userFirstName), value: user.firstName, mode: mode, onChange: (firstName) => onChange({ ...user, firstName }, isAdmin) }),
        React.createElement(DetailRow, { labelText: intl.formatMessage(messages.userLastName), value: user.lastName, mode: mode, onChange: (lastName) => onChange({ ...user, lastName }, isAdmin) }),
        React.createElement(DetailRow, { labelText: intl.formatMessage(messages.userEmail), value: user.email, mode: mode, onChange: (email) => onChange({ ...user, email }, isAdmin) }),
        React.createElement("div", { className: "gd-user-management-dialog-detail-row" },
            React.createElement("div", { className: "gd-user-management-dialog-detail-label" }, intl.formatMessage(messages.userMembership)),
            React.createElement("div", null,
                mode === "VIEW" &&
                    (isAdmin
                        ? intl.formatMessage(messages.userIsAdmin)
                        : intl.formatMessage(messages.userIsRegularUser)),
                mode === "EDIT" && (React.createElement(OrganizationMemberDropdown, { isDisabled: isBootstrapUser, isAdmin: isAdmin, onChange: (isAdminNow) => {
                        onChange(user, isAdminNow);
                        trackEvent(isAdmin ? "user-role-changed-to-admin" : "user-role-changed-to-member");
                    } })))),
        React.createElement(DetailRow, { labelText: intl.formatMessage(messages.userId), value: user.login, mode: mode, disabled: true, onChange: noop })));
};
//# sourceMappingURL=UserDetailsView.js.map