// (C) 2023-2024 GoodData Corporation
import React from "react";
import { invariant } from "ts-invariant";
const TelemetryContext = React.createContext(undefined);
TelemetryContext.displayName = "TelemetryContext";
export const TelemetryProvider = ({ trackEvent, children }) => {
    return React.createElement(TelemetryContext.Provider, { value: trackEvent }, children);
};
export const useTelemetry = () => {
    const trackEvent = React.useContext(TelemetryContext);
    invariant(trackEvent, "useTelemetry must be called in TelemetryContext with initialized value!");
    return trackEvent;
};
export function withTelemetry(WrappedComponent) {
    const ResultComponent = (props) => {
        return (React.createElement(TelemetryProvider, { trackEvent: props.onEvent },
            React.createElement(WrappedComponent, { ...props })));
    };
    ResultComponent.displayName = WrappedComponent.displayName;
    return ResultComponent;
}
//# sourceMappingURL=TelemetryContext.js.map