// (C) 2023 GoodData Corporation
import { useIntl } from "react-intl";
import React, { useCallback } from "react";
import { BackButton, ConfirmDialogBase } from "@gooddata/sdk-ui-kit";
import { messages } from "../locales.js";
import { AddUserContent } from "./AddUserContent.js";
import { useAddUsers } from "./usersHooks.js";
export const AddUser = ({ userGroupIds, grantedUsers, enableBackButton, onSubmit, onCancel, onClose, }) => {
    const intl = useIntl();
    const { addedUsers, isProcessing, onSelect, onAdd, onDelete } = useAddUsers(userGroupIds, onSubmit, onCancel);
    const backButtonRenderer = useCallback(() => {
        return React.createElement(BackButton, { onClick: onCancel, className: "s-user-management-navigate-back" });
    }, [onCancel]);
    return (React.createElement(ConfirmDialogBase, { className: "gd-share-dialog gd-share-dialog-add-users s-user-management-add-user", displayCloseButton: true, isPositive: true, isSubmitDisabled: addedUsers.length === 0 || isProcessing, showProgressIndicator: isProcessing, headline: intl.formatMessage(messages.addUserDialogTitle), cancelButtonText: intl.formatMessage(messages.addUserDialogCloseButton), submitButtonText: intl.formatMessage(messages.addUserDialogSaveButton), onCancel: onCancel, onSubmit: onAdd, onClose: onClose, headerLeftButtonRenderer: enableBackButton ? backButtonRenderer : undefined },
        React.createElement(AddUserContent, { grantedUsers: grantedUsers, addedUsers: addedUsers, onDelete: onDelete, onSelect: onSelect })));
};
//# sourceMappingURL=AddUser.js.map