// (C) 2021-2024 GoodData Corporation
import React from "react";
import { components as ReactSelectComponents, } from "react-select";
import { Typography, LoadingMask } from "@gooddata/sdk-ui-kit";
import { wrapMenuList } from "react-select-async-paginate";
import { isWorkspaceItem, isSelectErrorOption } from "../types.js";
import { getWorkspaceItemTestId } from "../utils.js";
export const EmptyRenderer = () => {
    return null;
};
export const LoadingMessageRenderer = () => {
    return (React.createElement("div", { className: "gd-share-dialog-loading-mask-container" },
        React.createElement(LoadingMask, { size: "small" })));
};
export const NoOptionsMessageRenderer = (props) => {
    return (React.createElement("div", { className: "s-user-management-no-option", "aria-label": "Share dialog no match" },
        React.createElement(ReactSelectComponents.NoOptionsMessage, { ...props })));
};
export const MenuListRendered = (props) => {
    return (React.createElement(ReactSelectComponents.MenuList, { ...props },
        React.createElement("div", { className: "s-user-management-menu", "aria-label": "Share dialog menu list" }, props.children)));
};
export const WrappedMenuListRenderer = wrapMenuList((props) => {
    return (React.createElement(ReactSelectComponents.MenuList, { ...props },
        React.createElement("div", { className: "s-user-management-menu", "aria-label": "Share dialog menu list" }, props.children)));
});
export const InputRendered = (props) => {
    return (React.createElement("div", { className: "gd-share-dialog-input s-user-management-input" },
        React.createElement(ReactSelectComponents.Input, { ...props })));
};
export const SingleValueInputRenderer = (props) => {
    if (props.hasValue) {
        return null;
    }
    return (React.createElement("div", { className: "gd-share-dialog-input s-user-management-input" },
        React.createElement(ReactSelectComponents.Input, { ...props })));
};
const OptionContentRenderer = (item) => {
    if (isWorkspaceItem(item.value)) {
        return React.createElement(React.Fragment, null,
            " ",
            item.value.title,
            " ");
    }
    return React.createElement(React.Fragment, null,
        " ",
        item.label,
        " ");
};
export const ErrorOptionRenderer = (errorOption) => {
    return (React.createElement("div", { className: "gd-share-dialog-option-error s-user-management-option-error", "aria-label": "Share dialog error" },
        React.createElement("span", { className: "gd-share-dialog-option-error-content" }, errorOption.label)));
};
export const OptionRenderer = (props) => {
    const { className, cx, isFocused, innerRef, innerProps, data } = props;
    if (isSelectErrorOption(data)) {
        return ErrorOptionRenderer(data);
    }
    const sTestStyle = isWorkspaceItem(data.value) ? getWorkspaceItemTestId(data.value) : "";
    const componentStyle = cx({
        option: true,
        "option--is-focused": isFocused,
    }, className);
    return (React.createElement("div", { ref: innerRef, className: `${componentStyle} ${sTestStyle}`, ...innerProps },
        React.createElement("div", { className: "option-content" }, OptionContentRenderer(data))));
};
export const GroupHeadingRenderer = (props) => {
    const { label } = props.data;
    return (React.createElement("div", { className: "gd-share-dialog-select-group-heading" },
        React.createElement(Typography, { tagName: "h3" }, label)));
};
//# sourceMappingURL=AsyncSelectComponents.js.map