// (C) 2024 GoodData Corporation
import React from "react";
import { useIntl } from "react-intl";
import cx from "classnames";
import { RemoveIcon } from "../../RemoveIcon.js";
import { usePermissionsDropdownState } from "./usePermissionsDropdownState.js";
import { WorkspaceIcon } from "./WorkspaceIcon.js";
import { workspaceGranularPermissionMessages } from "./locales.js";
import { getHumanReadablePermissionsTitle } from "./granularPermissionUtils.js";
export const GranularPermissionsWorkspaceItem = ({ workspace, onDelete, onClick, }) => {
    const { isDropdownOpen } = usePermissionsDropdownState();
    const intl = useIntl();
    const itemClassName = cx("s-user-management-workspace-item", "gd-share-dialog-grantee-item", {
        "is-active": isDropdownOpen,
    });
    const subtitle = getHumanReadablePermissionsTitle(workspace.permissions, intl);
    return (React.createElement("div", { className: itemClassName },
        React.createElement(RemoveIcon, { tooltipMessage: intl.formatMessage(workspaceGranularPermissionMessages.remove), onClick: () => onDelete(workspace) }),
        React.createElement("div", { className: "gd-grantee-content", onClick: () => onClick?.(workspace) },
            React.createElement("div", { className: "gd-grantee-content-label" }, workspace.title),
            React.createElement("div", { className: "gd-grantee-content-label gd-grantee-content-email", title: subtitle }, subtitle)),
        React.createElement(WorkspaceIcon, null)));
};
//# sourceMappingURL=GranularPermissionsWorkspaceItem.js.map