// (C) 2023-2024 GoodData Corporation
import React, { useCallback, useState } from "react";
import { useIntl } from "react-intl";
import cx from "classnames";
import { withBubble } from "@gooddata/sdk-ui-kit";
import { stringUtils } from "@gooddata/util";
import { useTelemetry } from "../../TelemetryContext.js";
import { hierarchicalPermissionMessages } from "./locales.js";
import { PermissionsDropdownList } from "./HierarchicalPermissionsDropdownList.js";
const trackPermissionChange = (trackEvent, subjectType, isHierarchical) => {
    if (subjectType === "user") {
        trackEvent(isHierarchical
            ? "user-permission-changed-to-hierarchy"
            : "user-permission-changed-to-single-workspace");
    }
    else {
        trackEvent(isHierarchical
            ? "group-permission-changed-to-hierarchy"
            : "group-permission-changed-to-single-workspace");
    }
};
const Dropdown = ({ workspace, subjectType, isDropdownDisabled, isDropdownOpen, toggleDropdown, onChange, className, }) => {
    const intl = useIntl();
    const trackEvent = useTelemetry();
    const [selectedPermission, setSelectedPermission] = useState(workspace.isHierarchical);
    const handleOnSelect = (isHierarchical) => {
        onChange({ ...workspace, isHierarchical });
        trackPermissionChange(trackEvent, subjectType, isHierarchical);
        setSelectedPermission(isHierarchical);
    };
    const handleClick = useCallback(() => {
        if (!isDropdownDisabled) {
            toggleDropdown();
        }
    }, [isDropdownDisabled, toggleDropdown]);
    const buttonValue = intl.formatMessage(selectedPermission ? hierarchicalPermissionMessages.enabled : hierarchicalPermissionMessages.disabled);
    return (React.createElement("div", { className: className },
        React.createElement("div", { className: cx("s-user-management-hierarchical-permission-button", "gd-granular-permission-button", "dropdown-button", `gd-granular-hierarchical-permission-button-${stringUtils.simplifyText(workspace.id)}`, {
                "is-active": isDropdownOpen,
                "gd-icon-navigateup": !isDropdownDisabled && isDropdownOpen,
                "gd-icon-navigatedown": !isDropdownDisabled && !isDropdownOpen,
                disabled: isDropdownDisabled,
                "gd-icon-right": !isDropdownDisabled,
            }), onClick: handleClick, "aria-label": "Share dialog granular permissions button" },
            React.createElement("div", { className: "s-user-management-button-title gd-granular-permission-button-title" }, buttonValue)),
        React.createElement(PermissionsDropdownList, { selectedPermission: selectedPermission, onSelect: handleOnSelect, toggleDropdown: toggleDropdown, isShowDropdown: isDropdownOpen, alignTo: `.gd-granular-hierarchical-permission-button-${stringUtils.simplifyText(workspace.id)}` })));
};
export const HierarchicalPermissionsDropdown = withBubble(Dropdown);
//# sourceMappingURL=HierarchicalPermissionsDropdown.js.map