// (C) 2023-2024 GoodData Corporation
import React, { useCallback } from "react";
import { useIntl, defineMessages } from "react-intl";
import cx from "classnames";
import { ItemsWrapper, Separator, Overlay } from "@gooddata/sdk-ui-kit";
import { workspacePermissionMessages } from "./locales.js";
import { PermissionDropdownItem } from "./PermissionDropdownItem.js";
const userGroupTooltipMessages = defineMessages({
    VIEW: { id: "userManagement.workspace.permissionGroup.view.tooltip" },
    VIEW_AND_SAVE_VIEWS: { id: "userManagement.workspace.permissionGroup.viewSaveViews.tooltip" },
    VIEW_AND_EXPORT: { id: "userManagement.workspace.permissionGroup.viewExport.tooltip" },
    VIEW_AND_EXPORT_AND_SAVE_VIEWS: {
        id: "userManagement.workspace.permissionGroup.viewExportSaveViews.tooltip",
    },
    ANALYZE: { id: "userManagement.workspace.permissionGroup.analyze.tooltip" },
    ANALYZE_AND_EXPORT: { id: "userManagement.workspace.permissionGroup.analyzeExport.tooltip" },
    MANAGE: { id: "userManagement.workspace.permissionGroup.manage.tooltip" },
});
const userTooltipMessages = defineMessages({
    VIEW: { id: "userManagement.workspace.permissionUser.view.tooltip" },
    VIEW_AND_SAVE_VIEWS: { id: "userManagement.workspace.permissionUser.viewSaveViews.tooltip" },
    VIEW_AND_EXPORT: { id: "userManagement.workspace.permissionUser.viewExport.tooltip" },
    VIEW_AND_EXPORT_AND_SAVE_VIEWS: {
        id: "userManagement.workspace.permissionUser.viewExportSaveViews.tooltip",
    },
    ANALYZE: { id: "userManagement.workspace.permissionUser.analyze.tooltip" },
    ANALYZE_AND_EXPORT: { id: "userManagement.workspace.permissionUser.analyzeExport.tooltip" },
    MANAGE: { id: "userManagement.workspace.permissionUser.manage.tooltip" },
});
const overlayAlignPoints = [{ align: "br tr" }];
const RemoveItem = ({ disabled, onClick }) => {
    const intl = useIntl();
    const className = cx("gd-list-item gd-menu-item gd-menu-item-remove", "s-user-management-permission-remove", {
        "is-disabled": disabled,
    });
    return (React.createElement("div", { className: className, onClick: onClick }, intl.formatMessage(workspacePermissionMessages.remove)));
};
export const PermissionsDropdownList = ({ items, subjectType, alignTo, isShowDropdown, selectedPermission, toggleDropdown, onSelect, onDelete, }) => {
    const tooltipSource = subjectType === "user" ? userTooltipMessages : userGroupTooltipMessages;
    const handleOnSelect = useCallback((permission) => {
        onSelect(permission);
        toggleDropdown();
    }, [onSelect, toggleDropdown]);
    const handleOnDelete = useCallback(() => {
        onDelete();
        toggleDropdown();
    }, [onDelete, toggleDropdown]);
    if (!isShowDropdown) {
        return null;
    }
    return (React.createElement(Overlay, { key: "GranularPermissionsSelect", alignTo: alignTo, alignPoints: overlayAlignPoints, className: "s-user-management-permissions-overlay", closeOnMouseDrag: true, closeOnOutsideClick: true, closeOnParentScroll: true, onClose: toggleDropdown },
        React.createElement(ItemsWrapper, { smallItemsSpacing: true },
            items.map((permissionItem) => {
                return (React.createElement(PermissionDropdownItem, { key: permissionItem.id, permission: permissionItem, selectedPermission: selectedPermission, toggleDropdown: toggleDropdown, onSelect: handleOnSelect, bubbleTextId: tooltipSource[permissionItem.id].id }));
            }),
            React.createElement(Separator, null),
            React.createElement(RemoveItem, { onClick: handleOnDelete }))));
};
//# sourceMappingURL=PermissionsDropdownList.js.map