// (C) 2023-2025 GoodData Corporation
import React from "react";
import { injectIntl } from "react-intl";
import { AbstractPluggableVisualization } from "./AbstractPluggableVisualization.js";
import { ErrorComponent, ErrorCodes, newErrorMapping, IntlWrapper } from "@gooddata/sdk-ui";
export class LocalizedUnknownVisualizationClass extends React.Component {
    errorDetails;
    componentDidMount() {
        this.props.onAfterRender?.();
    }
    constructor(props) {
        super(props);
        this.errorDetails = newErrorMapping(props.intl)[ErrorCodes.VISUALIZATION_CLASS_UNKNOWN];
    }
    render() {
        const { message, description } = this.errorDetails;
        return React.createElement(ErrorComponent, { message: message, description: description });
    }
}
export const IntlLocalizedUnknownVisualizationClass = injectIntl(LocalizedUnknownVisualizationClass);
export class PluggableUnknownChart extends AbstractPluggableVisualization {
    renderFun;
    unmountFun;
    constructor(props) {
        super(props);
        this.renderFun = props.renderFun;
        this.unmountFun = props.unmountFun;
    }
    getExtendedReferencePoint(referencePoint) {
        return Promise.resolve({ ...referencePoint, uiConfig: null });
    }
    getExecution(_options, _insight, _executionFactory) {
        const result = null;
        return result;
    }
    renderConfigurationPanel(_insight) { }
    renderVisualization(options, _insight, _executionFactory) {
        this.renderFun(React.createElement(IntlWrapper, { locale: options.locale },
            React.createElement(IntlLocalizedUnknownVisualizationClass, { onAfterRender: this.afterRender })), this.getElement());
        this.onLoadingChanged?.({ isLoading: false });
    }
    unmount() {
        this.unmountFun([this.getElement()]);
    }
}
//# sourceMappingURL=PluggableUnknownChart.js.map