// (C) 2021-2025 GoodData Corporation
import { DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT, MIN_VISUALIZATION_HEIGHT, MIDDLE_VISUALIZATION_HEIGHT, MIDDLE_VISUALIZATION_HEIGHT_FLEXIBLE_LAYOUT, MIN_VISUALIZATION_HEIGHT_FLEXIBLE_LAYOUT, MAX_NEW_VISUALIZATION_HEIGHT, MAX_VISUALIZATION_HEIGHT, } from "../constants.js";
import { addIntersectionFiltersToInsight, modifyBucketsAttributesForDrillDown } from "../drillDownUtil.js";
export class BaseChartDescriptor {
    getSizeInfo(_insight, layoutDescriptor, settings) {
        return {
            width: {
                default: settings.enableFlexibleDashboardLayout ? 4 : 6,
                min: 2,
                max: layoutDescriptor.gridColumnsCount,
            },
            height: {
                default: this.getDefaultHeight(settings),
                min: this.getMinHeight(settings),
                max: this.getMaxHeight(settings),
            },
        };
    }
    getDefaultHeight(settings) {
        const { enableKDWidgetCustomHeight, enableFlexibleDashboardLayout } = settings;
        if (!enableKDWidgetCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        if (enableFlexibleDashboardLayout) {
            return MIDDLE_VISUALIZATION_HEIGHT_FLEXIBLE_LAYOUT;
        }
        return MIDDLE_VISUALIZATION_HEIGHT;
    }
    getMinHeight(settings) {
        const { enableKDWidgetCustomHeight, enableFlexibleDashboardLayout } = settings;
        if (!enableKDWidgetCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        if (enableFlexibleDashboardLayout) {
            return MIN_VISUALIZATION_HEIGHT_FLEXIBLE_LAYOUT;
        }
        return MIN_VISUALIZATION_HEIGHT;
    }
    getMaxHeight(settings) {
        const { enableKDWidgetCustomHeight, enableFlexibleDashboardLayout } = settings;
        if (!enableKDWidgetCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        if (enableFlexibleDashboardLayout) {
            return MAX_NEW_VISUALIZATION_HEIGHT;
        }
        return MAX_VISUALIZATION_HEIGHT;
    }
    applyDrillDown(insight, drillDownContext, backendSupportsElementUris, enableDuplicatedLabelValuesInAttributeFilter) {
        const intersection = drillDownContext.event.drillContext.intersection;
        const withFilters = addIntersectionFiltersToInsight(insight, intersection, backendSupportsElementUris, enableDuplicatedLabelValuesInAttributeFilter);
        return modifyBucketsAttributesForDrillDown(withFilters, drillDownContext.drillDefinition);
    }
}
//# sourceMappingURL=BaseChartDescriptor.js.map