// (C) 2025 GoodData Corporation
import { insightSanitize } from "@gooddata/sdk-model";
import { PluggablePivotTableNext } from "./PluggablePivotTableNext.js";
import { BaseChartDescriptor } from "../baseChart/BaseChartDescriptor.js";
import { addIntersectionFiltersToInsight, modifyBucketsAttributesForDrillDown, sanitizeTableProperties, } from "../drillDownUtil.js";
import { DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT, MIN_VISUALIZATION_HEIGHT, MIN_VISUALIZATION_HEIGHT_FLEXIBLE_LAYOUT, } from "../constants.js";
export class PivotTableNextDescriptor extends BaseChartDescriptor {
    getFactory() {
        return (params) => new PluggablePivotTableNext(params);
    }
    getSizeInfo(_insight, layoutDescriptor, settings) {
        return {
            width: {
                default: settings.enableDashboardFlexibleLayout ? 4 : layoutDescriptor.gridColumnsCount,
                min: 2,
                max: layoutDescriptor.gridColumnsCount,
            },
            height: {
                default: this.getDefaultHeight(settings),
                min: this.getMinHeight(settings),
                max: this.getMaxHeight(settings),
            },
        };
    }
    getMinHeight(settings) {
        const { enableKDWidgetCustomHeight, enableDashboardFlexibleLayout } = settings;
        if (!enableKDWidgetCustomHeight) {
            return DASHBOARD_LAYOUT_DEFAULT_VIS_HEIGHT;
        }
        if (enableDashboardFlexibleLayout) {
            return MIN_VISUALIZATION_HEIGHT_FLEXIBLE_LAYOUT;
        }
        return MIN_VISUALIZATION_HEIGHT;
    }
    applyDrillDown(insight, drillDownContext, backendSupportsElementUris, enableDuplicatedLabelValuesInAttributeFilter) {
        const drillDownInsight = modifyBucketsAttributesForDrillDown(insight, drillDownContext.drillDefinition);
        const drillDownInsightWithFilters = addIntersectionFiltersToInsight(drillDownInsight, drillDownContext.event.drillContext.intersection, backendSupportsElementUris, enableDuplicatedLabelValuesInAttributeFilter);
        return sanitizeTableProperties(insightSanitize(drillDownInsightWithFilters));
    }
    getMeta() {
        return {
            documentationUrl: "https://sdk.gooddata.com/gooddata-ui/docs/pivot_table_component.html", // TODO: update link
            supportsExport: true,
            supportsZooming: false,
        };
    }
}
//# sourceMappingURL=PivotTableNextDescriptor.js.map