// (C) 2019-2024 GoodData Corporation
import React, { useMemo } from "react";
import { IntlProvider, createIntl } from "react-intl";
import { DefaultLocale, pickCorrectWording, resolveLocaleDefaultMessages, TranslationsCustomizationProvider, } from "@gooddata/sdk-ui";
import { translations } from "./translations.js";
import { LRUCache } from "lru-cache";
const INTL_CACHE_SIZE = 20;
const INTL_CACHE_KEY = "messages";
const intlCache = new LRUCache({ max: INTL_CACHE_SIZE });
export function createInternalIntl(locale = DefaultLocale) {
    /**
     * Because of issues described in the ticket FET-855, we decided to use this workaround.
     * After the issues that are described in the ticket are solved or at least reduced,
     * this workaround can be removed.
     */
    const cachedIntlConfig = intlCache.get(INTL_CACHE_KEY);
    if (cachedIntlConfig?.locale === locale) {
        return createIntl(cachedIntlConfig);
    }
    const settings = window.gdSettings;
    const strings = resolveLocaleDefaultMessages(locale, translations);
    intlCache.set(INTL_CACHE_KEY, {
        locale,
        messages: pickCorrectWording(strings, settings),
    });
    return createIntl(intlCache.get(INTL_CACHE_KEY));
}
export const InternalIntlWrapper = ({ locale = DefaultLocale, children, workspace, }) => {
    /**
     * Because of issues described in the ticket FET-855, we decided to use this workaround.
     * After the issues that are described in the ticket are solved or at least reduced,
     * this workaround can be removed.
     */
    const settings = window.gdSettings;
    const strings = resolveLocaleDefaultMessages(locale, translations);
    const messages = useMemo(() => pickCorrectWording(strings, settings), [strings, settings]);
    if (settings) {
        return (React.createElement(IntlProvider, { locale: locale, messages: messages }, children));
    }
    else {
        return (React.createElement(TranslationsCustomizationProvider, { translations: strings, workspace: workspace, render: (modifiedTranslations) => {
                return (React.createElement(IntlProvider, { key: locale, locale: locale, messages: modifiedTranslations }, children));
            } }));
    }
};
//# sourceMappingURL=internalIntlProvider.js.map