// (C) 2019-2025 GoodData Corporation
import React from "react";
import { useFetchOrganization } from "./useFetchOrganization.js";
import { UnexpectedSdkError } from "@gooddata/sdk-ui";
/**
 * @beta
 */
const OrganizationContext = React.createContext(null);
OrganizationContext.displayName = "OrganizationContext";
/**
 * @beta
 */
export const useOrganization = () => {
    const organization = React.useContext(OrganizationContext);
    if (!organization) {
        throw new UnexpectedSdkError("useOrganization must be used within a OrganizationProvider");
    }
    return organization;
};
/**
 * @beta
 */
export const OrganizationProvider = ({ children, backend, organizationId, }) => {
    const organization = useFetchOrganization({ backend, organizationId });
    return React.createElement(OrganizationContext.Provider, { value: organization }, children);
};
//# sourceMappingURL=OrganizationContext.js.map