// (C) 2024-2025 GoodData Corporation
import React from "react";
import { bem } from "../bem.js";
import { defineMessages, FormattedMessage, useIntl } from "react-intl";
import { Notification } from "./Notification.js";
const { b, e } = bem("gd-ui-ext-notification");
/**
 * Default implementation of the Notification component.
 *
 * @public
 */
export function DefaultNotification({ notification, markNotificationAsRead, onNotificationClick, closeNotificationsPanel, }) {
    if (notification.notificationType === "testNotification") {
        return React.createElement(UnsupportedNotificationType, null);
    }
    return (React.createElement(Notification, { notification: notification, markNotificationAsRead: markNotificationAsRead, onNotificationClick: onNotificationClick, closeNotificationsPanel: closeNotificationsPanel }));
}
function UnsupportedNotificationType() {
    const { formatMessage } = useIntl();
    return (React.createElement("div", { className: b({ isUnsupported: true }), role: "listitem", tabIndex: 0, "aria-label": formatMessage(messages.unsupportedNotificationType) },
        React.createElement("div", { className: e("unsupported") },
            React.createElement(FormattedMessage, { id: messages.unsupportedNotificationType.id }))));
}
const messages = defineMessages({
    unsupportedNotificationType: {
        id: "notifications.panel.unsupported.notification.type",
    },
});
//# sourceMappingURL=DefaultNotification.js.map