import { alignConfigToAlignPoint, Overlay, UiButton } from "@gooddata/sdk-ui-kit";
import React, { useRef, useState } from "react";
import { defineMessages, useIntl } from "react-intl";
import { NotificationTriggersDetailDialog } from "./NotificationTriggersDetailDialog.js";
const ALIGN_POINTS = [
    alignConfigToAlignPoint({
        triggerAlignPoint: "bottom-right",
        overlayAlignPoint: "top-right",
        offset: { x: 2, y: 3 },
    }),
    alignConfigToAlignPoint({
        triggerAlignPoint: "bottom-left",
        overlayAlignPoint: "top-left",
        offset: { x: 2, y: 3 },
    }),
];
const messages = defineMessages({
    triggersTitle: {
        id: "notifications.panel.triggers.title",
    },
});
/**
 * @internal
 */
export function NotificationTriggerDetail({ notification }) {
    const [isTriggersDialogOpen, setIsTriggersDialogOpen] = useState(false);
    const closeTriggersDialog = () => setIsTriggersDialogOpen(false);
    const toggleTriggersDialog = () => setIsTriggersDialogOpen((x) => !x);
    const intl = useIntl();
    const ref = useRef(null);
    const isSliced = notification.details.data.alert.attribute;
    const triggersTitle = isSliced ? getTriggersTitle(intl, notification.details.data.alert) : "";
    return (React.createElement(React.Fragment, null,
        React.createElement(UiButton, { ref: ref, onClick: (e) => {
                e.stopPropagation();
                toggleTriggersDialog();
            }, onKeyDown: (e) => {
                e.stopPropagation();
            }, variant: "tertiary", size: "small", label: triggersTitle, dataId: "notification-detail" }),
        isTriggersDialogOpen ? (React.createElement(Overlay, { isModal: false, alignTo: ref.current, alignPoints: ALIGN_POINTS, closeOnEscape: true, closeOnOutsideClick: true, closeOnParentScroll: false, closeOnMouseDrag: false, onClose: closeTriggersDialog },
            React.createElement(NotificationTriggersDetailDialog, { notification: notification, onClose: closeTriggersDialog }))) : null));
}
function getTriggersTitle(intl, alertDescription) {
    return intl.formatMessage(messages.triggersTitle, {
        triggeredCount: alertDescription.triggeredCount,
        totalCount: alertDescription.totalValueCount,
    });
}
//# sourceMappingURL=NotificationTriggersDetail.js.map