import React from "react";
import { DetailsDialog } from "../components/DetailsDialog.js";
import { bem } from "../bem.js";
import { useIntl, defineMessages } from "react-intl";
const { b, e } = bem("gd-ui-ext-notification-triggers-detail-dialog");
const messages = defineMessages({
    triggersTitle: {
        id: "notifications.panel.triggers.dialog.title",
    },
    newValue: {
        id: "notifications.panel.triggers.dialog.newValue",
    },
    truncatedValues: {
        id: "notifications.panel.triggers.dialog.truncatedValues",
    },
});
/**
 * @internal
 */
export function NotificationTriggersDetailDialog({ notification, onClose, }) {
    const intl = useIntl();
    const values = notification.details.data.alert?.currentValues;
    const hiddenValuesCount = (notification.details.data.alert?.triggeredCount ?? 0) - (values?.length ?? 0);
    return (React.createElement(DetailsDialog, { title: intl.formatMessage(messages.triggersTitle), content: React.createElement("div", { className: b() },
            React.createElement("div", { className: e("header") },
                React.createElement("div", { className: e("header-title") }, notification.details.data.alert.metric),
                React.createElement("div", { className: e("header-title") }, intl.formatMessage(messages.newValue))),
            React.createElement("div", { className: e("table") },
                React.createElement("div", { className: e("values-labels") }, values?.map((item, i) => (React.createElement("div", { key: i, className: e("values-label") }, item.labelValue)))),
                React.createElement("div", { className: e("values") }, values?.map((item, i) => (React.createElement("div", { key: i, className: e("values-value") }, item.primaryMetric.formattedValue))))),
            hiddenValuesCount > 0 && (React.createElement("div", { className: e("values-truncated") }, intl.formatMessage(messages.truncatedValues, {
                count: hiddenValuesCount,
            })))), onClose: onClose }));
}
//# sourceMappingURL=NotificationTriggersDetailDialog.js.map