// (C) 2024-2025 GoodData Corporation
import React from "react";
import { useElementSize, UiPagedVirtualList } from "@gooddata/sdk-ui-kit";
import { bem } from "../bem.js";
import { useIntl, defineMessages } from "react-intl";
const { b } = bem("gd-ui-ext-notifications-list");
/**
 * Default implementation of the NotificationsList component.
 *
 * @public
 */
export function DefaultNotificationsList({ Notification, NotificationsListEmptyState, NotificationsListErrorState, NotificationSkeletonItem, activeView, status, error, activeNotifications, markNotificationAsRead, onNotificationClick, hasNextPage, loadNextPage, itemHeight, itemsGap, itemPadding, skeletonItemsCount, maxListHeight = 0, closeNotificationsPanel, }) {
    const isError = status === "error";
    const isEmpty = status === "success" && activeNotifications?.length === 0;
    const isLoading = status === "loading" || status === "pending";
    const isSuccess = status === "success" && (activeNotifications?.length ?? 0) > 0;
    const { height, ref } = useElementSize();
    const { formatMessage } = useIntl();
    return (React.createElement("div", { className: b(), ref: (node) => {
            ref.current = node;
        }, role: "list", "aria-label": formatMessage(messages.notificationsListLabel) },
        isError ? React.createElement(NotificationsListErrorState, { error: error }) : null,
        isEmpty ? React.createElement(NotificationsListEmptyState, { activeView: activeView }) : null,
        isLoading || isSuccess ? (React.createElement(UiPagedVirtualList, { items: activeNotifications, itemHeight: itemHeight, itemsGap: itemsGap, itemPadding: itemPadding, skeletonItemsCount: skeletonItemsCount, hasNextPage: hasNextPage, loadNextPage: loadNextPage, isLoading: isLoading, maxHeight: Math.max(maxListHeight, height, (itemHeight + itemsGap) * skeletonItemsCount), SkeletonItem: NotificationSkeletonItem }, (notification) => (React.createElement(Notification, { notification: notification, markNotificationAsRead: markNotificationAsRead, onNotificationClick: onNotificationClick, closeNotificationsPanel: closeNotificationsPanel })))) : null));
}
const messages = defineMessages({
    notificationsListLabel: {
        id: "notifications.panel.notifications.list.label",
    },
});
//# sourceMappingURL=DefaultNotificationsList.js.map