import { UnexpectedSdkError } from "@gooddata/sdk-ui";
import React from "react";
import { useNotifications } from "./useNotifications.js";
const NotificationsContext = React.createContext(null);
NotificationsContext.displayName = "NotificationsContext";
/**
 * @internal
 */
export const useNotificationsContext = () => {
    const context = React.useContext(NotificationsContext);
    if (!context) {
        throw new UnexpectedSdkError("useNotificationsContext must be used within a NotificationsProvider");
    }
    return context;
};
/**
 * @internal
 */
export const NotificationsProvider = ({ children, backend, workspace, refreshInterval, itemsPerPage, enableScheduleNotifications, }) => {
    const notifications = useNotifications({
        backend,
        workspace,
        refreshInterval,
        itemsPerPage,
        enableScheduleNotifications,
    });
    return React.createElement(NotificationsContext.Provider, { value: notifications }, children);
};
//# sourceMappingURL=NotificationsContext.js.map