// (C) 2007-2024 GoodData Corporation
import React, { useCallback } from "react";
import { IntlProvider } from "react-intl";
import { DefaultLocale, TranslationsCustomizationProvider, resolveLocaleDefaultMessages, } from "@gooddata/sdk-ui";
import { translations } from "../../internal/utils/translations.js";
const formats = {
    time: {
        hhmm: {
            hour: "numeric",
            minute: "numeric",
        },
    },
    date: {
        shortWithoutYear: {
            day: "numeric",
            month: "short",
        },
        shortWithYear: {
            day: "numeric",
            month: "short",
            year: "numeric",
        },
    },
};
/**
 * @internal
 */
export const IntlWrapper = ({ children, locale = DefaultLocale }) => {
    const render = useCallback((modifiedTranslations) => (React.createElement(IntlProvider, { locale: locale, messages: modifiedTranslations, formats: formats }, children)), [locale, children]);
    return (React.createElement(TranslationsCustomizationProvider, { translations: resolveLocaleDefaultMessages(locale, translations), render: render }));
};
//# sourceMappingURL=IntlWrapper.js.map